==> owncloud-8.1.0p2.tgz: owncloud/apps/activity/l10n/de.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Deine Feed-URL ist ungültig",
    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    "All Activities" : "Alle Aktivitäten",
    "Activities by you" : "Aktivitäten von Dir",
    "Activities by others" : "Aktivitäten von Anderen",
    "\"remote user\"" : "„Entfernter Benutzer“",
    "in %s" : "unter %s",
    "%s and %s" : "%s und %s",
    ", " : ", ",
    "_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_::_%s and <strong class=\"tooltip\" title=\"%s\">%n more</strong>_" : ["%s und <strong class=\"tooltip\" title=\"%s\">%n mehr</strong>","%s und <strong class=\"tooltip\" title=\"%s\">%n weitere</strong>"],
    "_%s and %n more_::_%s and %n more_" : ["%s und %n mehr","%s und %n weitere"],
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because in the last hour the following things happened at %s" : "Du erhältst diese E-Mail, da in der letzten Stunde folgende Dinge auf %s geschehen sind",
    "You are receiving this email because in the last day the following things happened at %s" : "Du erhältst diese E-Mail, da am letzten Tag folgende Dinge auf %s geschehen sind",
    "You are receiving this email because in the last week the following things happened at %s" : "Du erhältst diese E-Mail, da in der letzten Woche folgende Dinge auf %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiterer","* und %n weitere"],
    "Notifications" : "Benachrichtigungen",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "List your own actions in the stream" : "Deine eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Deine eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Du E-Mail-Benachrichtigungen empfangen kannst, musst Du Deine E-Mail-Adresse einrichten.",
    "Send emails:" : "Sende E-Mails:",
    "Hourly" : "Stündlich",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Activity feed" : "Feed der Aktivitäten",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "No activity yet" : "Bislang keine Aktivitäten",
    "No more events to load" : "Keine weiteren Ereignisse zum Laden",
    "Files" : "Dateien"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.3.tgz: owncloud/apps/activity/l10n/de.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Aktivität",
    "Personal activity feed for %s" : "Persönlicher Feed der Aktivitäten für %s",
    "Your feed URL is invalid" : "Deine Feed-URL ist ungültig",
    "Your settings have been updated." : "Deine Einstellungen wurden aktualisiert.",
    "Mail" : "Mail",
    "Stream" : "Stream",
    "Activities" : "Aktivitäten",
    "Error loading activities" : "Fehler beim Laden der Aktivitäten",
    "No activities" : "Keine Aktivitäten",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} und {lastParameter}",
    "_{parameterList} and {linkStart}%n more{linkEnd}_::_{parameterList} and {linkStart}%n more{linkEnd}_" : ["{parameterList} und {linkStart}%n mehr{linkEnd}","{parameterList} und {linkStart}%n mehr{linkEnd}"],
    "in {directory}" : "in {directory}",
    "This stream will show events like additions, changes & shares" : "Dieser Stream zeigt Ereignisse wie Hinzugekommenes, Änderungen und Freigaben an",
    "There are no events for this filter" : "Keine Ereignisse für diesen Filter vorhanden",
    "Today" : "Heute",
    "Yesterday" : "Gestern",
    "\"remote user\"" : "„Entfernter Benutzer“",
    "Activity notification" : "Benachrichtigung über die Aktivitäten",
    "All Activities" : "Alle Aktivitäten",
    "Activities by you" : "Aktivitäten von Dir",
    "Activities by others" : "Aktivitäten von Anderen",
    "%s and %s" : "%s und %s",
    "Hello %s," : "Hallo %s,",
    "You are receiving this email because the following things happened at %s" : "Du erhältst diese E-Mail, da folgende Dinge auf %s geschehen sind",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* und %n weiterer","* und %n weitere"],
    "List your own actions in the stream" : "Deine eigenen Aktivitäten im Stream auflisten",
    "Notify about your own actions via email" : "Über Deine eigenen Aktivitäten via E-Mail benachrichtigen",
    "You need to set up your email address before you can receive notification emails." : "Bevor Du E-Mail-Benachrichtigungen empfangen kannst, musst Du Deine E-Mail-Adresse einrichten.",
    "Send emails:" : "Sende E-Mails:",
    "Hourly" : "Stündlich",
    "Daily" : "Täglich",
    "Weekly" : "Wöchentlich",
    "Activity feed" : "Feed der Aktivitäten",
    "Enable RSS feed" : "RSS-Feed aktivieren",
    "No activity yet" : "Bislang keine Aktivitäten",
    "No more events to load" : "Keine weiteren Ereignisse zum Laden",
    "Files" : "Dateien"
},
"nplurals=2; plural=(n != 1);");
